Document: gcl@EXT@-tk-doc
Title: GNU Common Lisp Tk Interface Documentation
Author: W. Schelter
Abstract: Documentation for Graphical Interface to GCL using TCL/Tk
Section: Programming

Format: DVI
Files: /usr/share/doc/gcl@EXT@/gcl@EXT@-tk*.dvi.gz

Format: PDF
Files: /usr/share/doc/gcl@EXT@/gcl@EXT@-tk*.pdf.gz

Format: HTML
Index: /usr/share/doc/gcl@EXT@/gcl@EXT@-tk.html/index.html
Files: /usr/share/doc/gcl@EXT@/gcl@EXT@-tk.html/*.html
